pub fn encrypt_from_file(
input_file: String,
output_dir: String,
) -> Result<EncryptFromFileResult>Expand description
Encrypt a file and store its chunks.
This function reads a file, splits it into chunks, encrypts them, and stores them in the specified directory.