pub struct ChunkInfo(/* private fields */);Expand description
This is - in effect - a partial decryption key for an encrypted chunk of data.
It holds pre- and post-encryption hashes as well as the original (pre-compression) size for a given chunk. This information is required for successful recovery of a chunk, as well as for the encryption/decryption of it’s two immediate successors, modulo the number of chunks in the corresponding DataMap.
Implementations