pub struct DataMap(/* private fields */);Expand description
Holds the information that is required to recover the content of the encrypted file.
This is held as a vector of ChunkInfo, i.e. a list of the file’s chunk hashes.
Only files larger than 3072 bytes (3 * MIN_CHUNK_SIZE) can be self-encrypted.
Smaller files will have to be batched together.
Implementations
Sourceimpl DataMap
impl DataMap
pub fn into_reference(val: DataMap, env: Env) -> Result<Reference<DataMap>>
pub fn into_instance(self, env: Env) -> Result<ClassInstance<DataMap>>
Sourceimpl DataMap
impl DataMap
Sourcepub fn new(keys: Vec<&ChunkInfo>) -> Self
pub fn new(keys: Vec<&ChunkInfo>) -> Self
A new instance from a vec of partial keys.
Sorts on instantiation. The algorithm requires this to be a sorted list to allow get_pad_iv_key to obtain the correct pre-encryption hashes for decryption/encryption.
Sourcepub fn with_child(keys: Vec<&ChunkInfo>, child: BigInt) -> Result<Self>
pub fn with_child(keys: Vec<&ChunkInfo>, child: BigInt) -> Result<Self>
Creates a new DataMap with a specified child value
Sourcepub fn original_file_size(&self) -> usize
pub fn original_file_size(&self) -> usize
Original (pre-encryption) size of the file.