EncryptedChunk

Struct EncryptedChunk 

pub struct EncryptedChunk(/* private fields */);
A JavaScript wrapper for the EncryptedChunk struct.

EncryptedChunk represents an encrypted piece of data along with its metadata like size and hash. Chunks are stored separately and referenced by the DataMap.

Implementations

Source

impl EncryptedChunk

pub fn instance_of<V: NapiRaw>(env: Env, value: V) -> Result<bool>

Source

impl EncryptedChunk

Source

impl EncryptedChunk

pub fn content_size(&self) -> u32

Get the size of the original content before encryption.

pub fn hash(&self) -> Uint8Array

Get the hash of the encrypted chunk.

pub fn content(&self) -> Uint8Array

Get the content of the encrypted chunk.